@@ -18,16 +18,15 @@
 #undef CHARLS_ATTRIBUTE
 #undef CHARLS_DEPRECATED
 #undef CHARLS_C_VOID
-
-#undef IN_
-#undef IN_OPT_
-#undef IN_Z_
-#undef IN_READS_BYTES_
-#undef OUT_
-#undef OUT_OPT_
-#undef OUT_WRITES_BYTES_
-#undef OUT_WRITES_Z_
-#undef RETURN_TYPE_SUCCESS_
+#undef CHARLS_IN
+#undef CHARLS_IN_OPT
+#undef CHARLS_IN_Z
+#undef CHARLS_IN_READS_BYTES
+#undef CHARLS_OUT
+#undef CHARLS_OUT_OPT
+#undef CHARLS_OUT_WRITES_BYTES
+#undef CHARLS_OUT_WRITES_Z
+#undef CHARLS_RETURN_TYPE_SUCCESS
 #undef CHARLS_CHECK_RETURN
 #undef CHARLS_RET_MAY_BE_NULL
 
