@@ -12,6 +12,7 @@
 
 using Microsoft::VisualStudio::CppUnitTestFramework::Assert;
 using std::array;
+using std::numeric_limits;
 
 namespace charls { namespace test {
 
@@ -42,7 +43,7 @@ public:
         array<uint8_t, 1> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        assert_expect_exception(jpegls_errc::destination_buffer_too_small, [&] { writer.write_start_of_image(); });
+        assert_expect_exception(jpegls_errc::destination_buffer_too_small, [&writer] { writer.write_start_of_image(); });
         Assert::AreEqual(static_cast<size_t>(0), writer.bytes_written());
     }
 
@@ -51,19 +52,72 @@ public:
         array<uint8_t, 2> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        writer.write_end_of_image();
+        writer.write_end_of_image(false);
 
         Assert::AreEqual(static_cast<size_t>(2), writer.bytes_written());
         Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
         Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::end_of_image), buffer[1]);
     }
 
+    TEST_METHOD(write_end_of_image_even_no_extra_byte_needed) // NOLINT
+    {
+        array<uint8_t, 2> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        writer.write_end_of_image(true);
+
+        Assert::AreEqual(static_cast<size_t>(2), writer.bytes_written());
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
+        Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::end_of_image), buffer[1]);
+    }
+
+    TEST_METHOD(write_end_of_image_even_extra_byte_needed) // NOLINT
+    {
+        array<uint8_t, 5 + 3> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        // writer.
+        constexpr uint8_t comment{99};
+        writer.write_comment_segment({&comment, 1});
+        writer.write_end_of_image(true);
+
+        Assert::AreEqual(static_cast<size_t>(8), writer.bytes_written());
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
+        Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::comment), buffer[1]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[2]);
+        Assert::AreEqual(static_cast<uint8_t>(3), buffer[3]);
+        Assert::AreEqual(static_cast<uint8_t>(99), buffer[4]);
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[5]);
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[6]);
+        Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::end_of_image), buffer[7]);
+    }
+
+    TEST_METHOD(write_end_of_image_even_extra_byte_needed_not_enabled) // NOLINT
+    {
+        array<uint8_t, 5 + 2> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        // writer.
+        constexpr uint8_t comment{99};
+        writer.write_comment_segment({&comment, 1});
+        writer.write_end_of_image(false);
+
+        Assert::AreEqual(static_cast<size_t>(7), writer.bytes_written());
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
+        Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::comment), buffer[1]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[2]);
+        Assert::AreEqual(static_cast<uint8_t>(3), buffer[3]);
+        Assert::AreEqual(static_cast<uint8_t>(99), buffer[4]);
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[5]);
+        Assert::AreEqual(static_cast<uint8_t>(jpeg_marker_code::end_of_image), buffer[6]);
+    }
+
     TEST_METHOD(write_end_of_image_in_too_small_buffer) // NOLINT
     {
         array<uint8_t, 1> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        assert_expect_exception(jpegls_errc::destination_buffer_too_small, [&] { writer.write_end_of_image(); });
+        assert_expect_exception(jpegls_errc::destination_buffer_too_small, [&writer] { writer.write_end_of_image(false); });
         Assert::AreEqual(static_cast<size_t>(0), writer.bytes_written());
     }
 
@@ -131,7 +185,7 @@ public:
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[28]);
         Assert::AreEqual(static_cast<uint8_t>(96), buffer[29]);
 
-        // header.horizontal_resolution = 1024;
+        // header.horizontal_resolution = 1024
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[30]);
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[31]);
         Assert::AreEqual(static_cast<uint8_t>(4), buffer[32]);
@@ -155,7 +209,7 @@ public:
                             1024};
 
         assert_expect_exception(jpegls_errc::destination_buffer_too_small,
-                                [&] { writer.write_spiff_header_segment(header); });
+                                [&writer, &header] { writer.write_spiff_header_segment(header); });
         Assert::AreEqual(static_cast<size_t>(0), writer.bytes_written());
     }
 
@@ -192,7 +246,7 @@ public:
         array<uint8_t, 10> buffer{};
         jpeg_stream_writer writer{{buffer.data(), buffer.size()}};
 
-        array<uint8_t, 2> data{0x77, 0x66};
+        const array<uint8_t, 2> data{0x77, 0x66};
 
         writer.write_spiff_directory_entry(2, data.data(), data.size());
 
@@ -223,8 +277,10 @@ public:
         array<uint8_t, 19> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        writer.write_start_of_frame_segment(100, UINT16_MAX, bits_per_sample, component_count);
+        const bool oversized_image{
+            writer.write_start_of_frame_segment({100, numeric_limits<uint16_t>::max(), bits_per_sample, component_count})};
 
+        Assert::IsFalse(oversized_image);
         Assert::AreEqual(static_cast<size_t>(19), writer.bytes_written());
 
         Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
@@ -251,6 +307,45 @@ public:
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[18]);
     }
 
+    TEST_METHOD(write_start_of_frame_segment_large_image) // NOLINT
+    {
+        constexpr int32_t bits_per_sample{8};
+        constexpr int32_t component_count{3};
+
+        array<uint8_t, 19> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        const bool oversized_image{writer.write_start_of_frame_segment(
+            {100, numeric_limits<uint16_t>::max() + 1U, bits_per_sample, component_count})};
+
+        Assert::IsTrue(oversized_image);
+        Assert::AreEqual(static_cast<size_t>(19), writer.bytes_written());
+
+        Assert::AreEqual(static_cast<uint8_t>(0xFF), buffer[0]);
+        Assert::AreEqual(static_cast<uint8_t>(0xF7), buffer[1]); // JPEG_SOF_55
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[2]);    // 6 + (3 * 3) + 2 (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(17), buffer[3]);   // 6 + (3 * 3) + 2 (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(bits_per_sample), buffer[4]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[5]); // height (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[6]); // height (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[7]); // width (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[8]); // width (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(component_count), buffer[9]);
+
+        Assert::AreEqual(static_cast<uint8_t>(1), buffer[10]);
+        Assert::AreEqual(static_cast<uint8_t>(0x11), buffer[11]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[12]);
+
+        Assert::AreEqual(static_cast<uint8_t>(2), buffer[13]);
+        Assert::AreEqual(static_cast<uint8_t>(0x11), buffer[14]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[15]);
+
+        Assert::AreEqual(static_cast<uint8_t>(3), buffer[16]);
+        Assert::AreEqual(static_cast<uint8_t>(0x11), buffer[17]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[18]);
+    }
+
+
     TEST_METHOD(write_start_of_frame_marker_segment_with_low_boundary_values) // NOLINT
     {
         constexpr int32_t bits_per_sample{2};
@@ -259,7 +354,7 @@ public:
         array<uint8_t, 13> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        writer.write_start_of_frame_segment(0, 0, bits_per_sample, component_count);
+        writer.write_start_of_frame_segment({1, 1, bits_per_sample, component_count});
 
         Assert::AreEqual(buffer.size(), writer.bytes_written());
         Assert::AreEqual(static_cast<uint8_t>(bits_per_sample), buffer[4]);
@@ -271,18 +366,19 @@ public:
         array<uint8_t, 775> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
 
-        writer.write_start_of_frame_segment(UINT16_MAX, UINT16_MAX, 16, UINT8_MAX);
+        writer.write_start_of_frame_segment(
+            {numeric_limits<uint16_t>::max(), numeric_limits<uint16_t>::max(), 16, numeric_limits<uint8_t>::max()});
 
         Assert::AreEqual(buffer.size(), writer.bytes_written());
         Assert::AreEqual(static_cast<uint8_t>(16), buffer[4]);
-        Assert::AreEqual(static_cast<uint8_t>(UINT8_MAX), buffer[9]);
+        Assert::AreEqual(numeric_limits<uint8_t>::max(), buffer[9]);
 
-        Assert::AreEqual(static_cast<uint8_t>(UINT8_MAX), buffer[buffer.size() - 3]); // Last component index.
+        Assert::AreEqual(numeric_limits<uint8_t>::max(), buffer[buffer.size() - 3]); // Last component index.
     }
 
     TEST_METHOD(write_color_transform_segment) // NOLINT
     {
-        const color_transformation transformation = color_transformation::hp1;
+        constexpr color_transformation transformation = color_transformation::hp1;
 
         array<uint8_t, 9> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
@@ -301,7 +397,7 @@ public:
 
     TEST_METHOD(write_jpegls_extended_parameters_marker_and_serialize) // NOLINT
     {
-        const jpegls_pc_parameters presets{2, 1, 2, 3, 7};
+        constexpr jpegls_pc_parameters presets{2, 1, 2, 3, 7};
 
         array<uint8_t, 15> buffer{};
         jpeg_stream_writer writer({buffer.data(), buffer.size()});
@@ -333,6 +429,33 @@ public:
         Assert::AreEqual(static_cast<uint8_t>(7), buffer[14]);
     }
 
+    TEST_METHOD(write_jpegls_preset_parameters_segment_for_oversized_image_dimensions) // NOLINT
+    {
+        array<uint8_t, 14> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        writer.write_jpegls_preset_parameters_segment(100, numeric_limits<uint32_t>::max());
+        Assert::AreEqual(buffer.size(), writer.bytes_written());
+
+        // Parameter ID.
+        Assert::AreEqual(static_cast<uint8_t>(0x4), buffer[4]);
+
+        // Wxy
+        Assert::AreEqual(static_cast<uint8_t>(4), buffer[5]);
+
+        // Height (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[6]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[7]);
+        Assert::AreEqual(static_cast<uint8_t>(0), buffer[8]);
+        Assert::AreEqual(static_cast<uint8_t>(100), buffer[9]);
+
+        // Width (in big endian)
+        Assert::AreEqual(static_cast<uint8_t>(255), buffer[10]);
+        Assert::AreEqual(static_cast<uint8_t>(255), buffer[11]);
+        Assert::AreEqual(static_cast<uint8_t>(255), buffer[12]);
+        Assert::AreEqual(static_cast<uint8_t>(255), buffer[13]);
+    }
+
     TEST_METHOD(write_start_of_scan_marker) // NOLINT
     {
         array<uint8_t, 10> buffer{};
@@ -348,6 +471,20 @@ public:
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[8]); // ILV parameter.
         Assert::AreEqual(static_cast<uint8_t>(0), buffer[9]); // transformation.
     }
+
+    TEST_METHOD(rewind) // NOLINT
+    {
+        array<uint8_t, 10> buffer{};
+        jpeg_stream_writer writer({buffer.data(), buffer.size()});
+
+        writer.write_start_of_scan_segment(1, 2, interleave_mode::none);
+        writer.rewind();
+        buffer[4] = 0;
+        writer.write_start_of_scan_segment(1, 2, interleave_mode::none);
+
+        Assert::AreEqual(buffer.size(), writer.bytes_written());
+        Assert::AreEqual(static_cast<uint8_t>(1), buffer[4]); // component count.
+    }
 };
 
 }} // namespace charls::test
